**************************************************************************************************
* Mexico-TAXBEN - The Mexican Income Tax, Social Security Contributions and Indirect Tax Simulator
*
* Program name: create_MEXTAX_input_data.do
* Program purpose: This program uses data files created in create_processed_data.do
*                    from ENIGH 2008 raw files

* Program created: September 2010, by Laura Abramovsky
* Program updated: 19 November 2010, by David Phillips
* Program updated: 02 December 2010, by Laura Abramovsky, 03 December by David
* Program updated: 04 March 2011, by Laura Abramovsky
* Program updated: 13 December 2012, by David Phillips
**************************************************************************************************


* set stata parameters.
clear all
cap log close
set mem 200m  /* Note:  set this so that there is sufficient memory to handle your input file */
set more off


* Assign directories

cd "W:\Mexico_Fiscal_Reforms2\Mexico Processed Data\"
global raw_data "W:\Mexico_Fiscal_Reforms2\Mexico Raw Data\"

* Specify log file

cap log close
log using "create_MEXTAX_input_data.log", replace




noi di "************"
noi di " Adult file "
noi di "************"

    use pobla08.dta, clear

    keep folioviv foliohog numren rel_head sexo edad n_instr161 trabajo_2

    noi di " merge gross income"
    noi di "*******************"

    sort folioviv foliohog numren

    merge folioviv foliohog numren using incomes2.dta

    drop _merge

    foreach X of numlist 1(1)20 {

    	replace inc`X' = 0 if inc`X' == .

    }
    replace formal_w = 0 if formal_w==.


    note: this dataset is at the [ individual (numren) - residence (folioviv) - household (foliohog) ] level
    note: source is ENEIGH 2008

    sort folioviv foliohog numren
    save adult.dta, replace



noi di "****************"
noi di "Household file"
noi di "****************"

    noi di "*************************"
    noi di "append total expenditure "
    noi di "*************************"

    * monetary expenditure
    use "gastos_agg.dta", clear

    foreach var in gastodiario gastoeduca {
        append using "`var'_agg.dta"
        }

    collapse (sum) gas_mon, by(folioviv foliohog)

    label var gas_mon "Montly Monetary Expenditure"

    * imputed rent
    sort folioviv foliohog
    merge folioviv foliohog using "irent.dta"
    tab _mer
    drop if _m==2
    drop _mer

    * nonmonetary categories
    sort folioviv foliohog
    merge folioviv foliohog using "nomonet_agg.dta"
    tab _mer
    drop if _m==2
    drop _mer

    egen totexp= rsum(gas_mon irent autocon reminkind transfer)
    replace totexp = totexp*12
    label var totexp "Annual total expenditure - monet and nonmonet"

    gen monexp = gas_mon *12
    label var monexp "Annual total monetary expenditure"

    egen nmonexp = rsum (irent autocon reminkind transfer)
    replace nmonexp = nmonexp *12
    label var nmonexp "Annual total nonmonetary expenditure"

    keep folioviv foliohog totexp monexp nmonexp
    sort folioviv foliohog

    save "hh_expenditure.dta", replace


    noi di "********************************"
    noi di "append  (and deal with missing)"
    noi di "total income "
    noi di "********************************"

    * net monet
    use "ingresos_mon_net_agg.dta", clear

    * imputed rent
    sort folioviv foliohog
    merge folioviv foliohog using "irent.dta"
    tab _mer
    drop if _m==2
    drop _mer

    * nonmonetary categories
    sort folioviv foliohog
    merge folioviv foliohog using "nomonet_agg.dta"
    tab _mer
    drop if _m==2
    drop _mer

    * gross labour income

    * deal with missing income

                ******Altimir Factor SHCP (2010) based in ENIGH 2008******
                *monetary capital income (inc_cap):12.63229228
                *monetary employment income (inc_emp, inc_oemp): 1.19149605
                ******Villarreal et al factor for employment income
                *employment income: 1.45
                ** NOTE: we may want to gross up different nl income by different factors
                ***NOTE: DO WE NEED TO GROSS UP NON MONETARY INCOME?

    * create different categories
    gen double moninc_e=inc_emp*12

    egen moninc=rsum(inc_emp inc_semp inc_cap inc_tran inc_oemp inc_other)
    replace moninc=moninc*12

    egen totinc=rsum(inc_emp inc_semp inc_cap inc_tran inc_oemp inc_other  irent autocon reminkind transfer)
    replace totinc=totinc*12

    label var moninc_e "Annual net employment monetary (current) income"
    label var moninc "Annual net monetary (current) income"
    label var totinc "Annual net total (current) income (monet+nonmonet)"

    keep totinc moninc_e moninc folioviv foliohog
    sort folioviv foliohog
    save hh_tot_income.dta, replace


    noi di "***************************************"
    noi di "merge expenditure and income to hogares"
    noi di "    and other variables                "
    noi di "***************************************"

    use "hogares.dta", clear
    keep  folioviv foliohog residentes factor estrato ubica_geo est_dis  upm
    sort folioviv foliohog

    noi di "expenditure"
    noi di "***********"
    merge folioviv foliohog using "hh_expenditure.dta"
    tab _m

    * this is weird, there are HH that are only present in the expenditure data
    drop if _m==2
    drop _m
    erase "hh_expenditure.dta"

    noi di "income"
    noi di "*******"
    sort folioviv foliohog
    merge folioviv foliohog using "hh_tot_income.dta"
    tab _me
    drop if _m==2
    drop _me

    * TO DO - merge income and expenditure measures from CONEVAL - create variable "folio"

    noi di "merge HH memebrs <12 years"
    noi di "create equivalence scales"
    noi di "**************************"

    preserve

    use folioviv foliohog mayores menores using "W:\Mexico_Fiscal_Reforms2\Mexico Raw Data\concen.dta", clear

    sort folioviv foliohog

    save "hh_menores.dta", replace

    restore

    sort folioviv foliohog
    merge folioviv foliohog using "hh_menores.dta"
    tab _m
    drop if _m==2
    drop _m

    label var menores "Number of HH members under 12 years old"
    label var mayores "Number of HH members 12 years old or older"

    erase "hh_menores.dta"

    gen eqsc_5030=1+(mayores-1)*(0.5)+menores*(0.3)
    gen eqsc_8050=1+(mayores-1)*(0.8)+menores*(0.5)
    gen eqsc_100100=1+(mayores-1)*(1)+menores*(1)

    noi di "merge number of adults and of children"
    noi di "**************************************"

    ** child , adult
   gen child = menores
   gen adult = mayores

   replace residentes = mayores + menores


   gen numren = "01"

   noi di "merge number of families"
   noi di " and hhtype"
   noi di "************************"

   sort folioviv foliohog
   merge folioviv foliohog using "hhtype.dta", keep(folioviv foliohog hhtype numfam)

   tab _merge
   keep if _merge==3
   drop _merge

   order folioviv foliohog numren hhtype numfam residentes mayores menores adult child eqsc_* factor estrato est_dis upm ubica_geo
   sort folioviv foliohog numren
   save "household.dta", replace



noi di "*******************"
noi di "Consumption file "
noi di "*******************"

     noi di " append all expenditure together"

    use "gastos_agg_cat.dta", clear

    foreach var in gastodiario gastoeduca {
        append using "`var'_agg_cat.dta"
        }

    collapse (sum) gas_mon, by(folioviv foliohog expnum)

    drop if expnum==""

    rename gas_mon _
    reshape wide _, i(folioviv foliohog) j(expnum) string

    gen exp32=0
    gen exp33=0
    gen exp35=0
    gen exp39=0
    gen exp40=0
    gen exp52=0
    gen exp54=0
    gen exp55=0

    forvalues x=1(1)60 {
    cap rename _exp`x' exp`x'
    replace exp`x' = 0 if exp`x'==.
    replace exp`x' = exp`x'*12
    }

    gen numren = "01"

    order folioviv foliohog numren exp2 exp3 exp4 exp5 exp6 exp7 exp8 exp9 exp10 exp11 exp12 exp13 exp14 exp15 exp16 exp17 exp18 exp19	exp20	exp21	exp22	exp23	exp24	exp25	exp26	exp27	exp28	exp29	exp30	exp31	exp32	exp33	exp34	exp35	exp36	exp37	exp38	exp39	exp40	exp41	exp42	exp43	exp44	exp45	exp46	exp47	exp48	exp49	exp50	exp51	exp52	exp53	exp54	exp55	exp56	exp57	exp58	exp59	exp60

    * label vars

    sort folioviv foliohog numren

    note: this dataset is at the [ residence (folioviv) - household (foliohog) ] level
    note: this dataset has information on monetary consumption only
    note: source is ENEIGH 2008
    save "consumption_monetary.dta", replace

    cap log close
