**************************************************************************************************
* Mexico-TAXBEN - The Mexican Income Tax, Social Security Contributions and Indirect Tax Simulator
*
* Program name: create_expenditure_demand.do
* Program purpose: This program uses data files created in create_processed_data.do
*                    on expenditure to construct the expenditures, shares and prices for different goods

* Program created: March 2011, by David Phillips
* Program updated: 01 March 2011, by David Phillips
* Program updated: 01 March 2011, by David Phillips 
**************************************************************************************************


cd "W:\Mexico_Fiscal_Reforms2"

global data     "Mexico Raw Data"

global data_pro "Mexico Processed Data"

global dofile   "Mexico Raw Data\Do Files"

global ubica  "W:\Mexico_Fiscal_Reforms2\Mexico Raw Data\ubica_geo\\"

global processed_data "W:\Mexico_Fiscal_Reforms2\Mexico Raw Data\BOMPrices\processed data\\"


use "$data_pro\gastos.dta", clear

append using "$data_pro\gastodiario.dta"

append using "$data_pro\gastoeduca.dta"

keep folioviv foliohog clave clave_letter gasto gas_mon gas_tri descripcion iva vat

gen multiple = gasto/gas_mon

replace multiple = 1/4.333 if multiple>=0.22 & multiple<=0.26
replace multiple = 1 if multiple>=0.98 & multiple<=1.02 
replace multiple = 3 if multiple>=2.96 & multiple<=3.04
replace multiple = 6 if multiple>=5.94 & multiple<=6.05  


/** SET UP THE EXPENDITURE CATEGORIES */

* untaxed food
gen spend1 = gas_mon if (clave>="A001" & clave<="A197") |(clave>="A203" & clave<="A218") | clave=="A242"
* taxed food
gen spend2 = gas_mon if (clave>="A198" & clave<="A202") |(clave>="A219" & clave<="A222") |(clave>="A243" & clave<="A247") | clave=="T901"
* alcohol and tobacco (taxed)
gen spend3 = gas_mon if (clave>="A223" & clave<="A241")
* taxed clothing and footware
gen spend4 = gas_mon if (clave>="H001" & clave<="H136") | clave=="T908"
* taxed hhold goods, services, communications and electronics
gen spend5 = gas_mon if (clave>="C001" & clave<="C024") | (clave>="G009" & clave<="G010")| (clave>="G020" & clave<="G022")| (clave>="I001" & clave<="I026")| (clave>="K001" & clave<="K044")| (clave>="G009" & clave<="G010")| (clave>="F001" & clave<="F009")| (clave>="L001" & clave<="L022")| clave=="T903"| clave=="T907" | clave=="T909" | clave=="T911" | clave=="G008"
* non-taxed household goods, services etc
gen spend6 = gas_mon if (clave>="G011" & clave<="G019") | clave=="G007"
* taxed trasport goods, services and petrol
gen spend7 = gas_mon if (clave>="F010" & clave<="F017") |(clave>="M002" & clave<="M004") | clave=="M006" |(clave>="M012" & clave<="M018") | clave=="T902"| clave=="T906"| clave=="T913"
* untaxed trasport goods, services and petrol
gen spend8 = gas_mon if (clave>="B001" & clave<="B007") |clave=="M001" | clave=="E013"
* gen non-taxed health and educ
gen spend9 = gas_mon if (clave>="J020" & clave<="J035") |(clave>="J044" & clave<="J059") | clave=="J001"| clave=="J004"| clave=="J005"| clave=="J007"| clave=="J008"| clave=="J013"| clave=="J016"| clave=="J017"| clave=="J018"| clave=="J036"| clave=="J039"| clave=="J062"| clave=="J072"| clave=="J009"| clave=="J010"| clave=="J014"| clave=="J037"| clave=="J038"| clave=="J042"| clave=="J059"| clave=="J063"| clave=="J064"| clave=="T910" | clave=="E014" | clave=="E015"
* gen taxed personal goods and services
gen spend10= gas_mon if (clave>="J065" & clave<="J071") |(clave>="D001" & clave<="D026") | clave=="E016"| clave=="E018"| clave=="E019"| clave=="T905"| clave=="J002"| clave=="J003"| clave=="J006"| clave=="J011"| clave=="J012"| clave=="J015"| clave=="J019"| clave=="J040"| clave=="J041"| clave=="J043"| clave=="J060"| clave=="J061"| clave=="T904"
* gen leisure and hotels
gen spend11= gas_mon if (clave>="E020" & clave<="E033") | (clave>="L023" & clave<="L029") | (clave>="N003" & clave<="N005") | clave=="T912"
* gen other
gen spend12 = gas_mon if clave=="N001" | clave=="N002" | clave=="T912"

label var spend1 "Non-VAT food"
label var spend2 "VAT food and meals out"
label var spend3 "VAT and Excise Drinks and Tobacco"
label var spend4 "VAT clothing and footwear"
label var spend5 "VAT Hhold goods, services and communications"
label var spend6 "Non-VAT Hhold goods, services and communications"
label var spend7 "VAT transport services and petrol"
label var spend8 "Non-VAT transport services"
label var spend9 "Non-VAT health and education"
label var spend10 "VAT health and personal goods and services"
label var spend11 "Leisure and hotels"
label var spend12 "Other services"

foreach X of numlist 1(1)12 {

	replace spend`X' = 0 if spend`X' ==.

}

collapse (sum) spend1 spend2 spend3 spend4 spend5 spend6 spend7 spend8 spend9 spend10 spend11 spend12, by(folioviv foliohog)

egen tspend = rsum(spend1-spend12)

foreach X of numlist 1(1)12 {

	gen share`X' = spend`X'/tspend

}

    ***** this is from Hector ISR 2008
    g decena = substr(folioviv,3,1)
    label var decena "referes to the 10 days when the survey was done, used to calculate montly income"

/** GET DATA ON PRICES USING MUNI_CODES, MATCHED CITIES, AND CITY LEVEL PRICES **/

sort folioviv foliohog

merge folioviv foliohog using "$data_pro\hogares.dta", keep(ubica_geo factor)

tab _merge

keep if _merge==3

drop _merge

destring ubica_geo, replace

sort ubica_geo

merge ubica_geo using "$ubica\\ubica_geo_city.dta"

tab _merge

drop _merge

destring decena, replace

sort city decena

merge city decena using "$processed_data\\price_level_dec_2008.dta" 

tab _merge

keep if _merge==3

drop _merge

gen numren = "01"

sort folioviv foliohog numren

merge folioviv foliohog numren using "W:\Mexico_Fiscal_Reforms2\Mexico Processed Data\household.dta", keep(adult child moninc eqsc_5030 eqsc_8050 eqsc_100100)

tab _merge
keep if _merge==3
drop _merge

/** NOW CALCULATING THE LOG PRICES, ETC **/

foreach X of numlist 1(1)12 {

	rename IPm`X' p`X'
	gen lnp`X' = ln(p`X')
	rename share`X' w`X'

}

gen exp = tspend/eqsc_8050
gen lnexp = ln(exp)

/** SAVING THE BASELINE VERSION OF THE DATA FOR DEMAND MODEL **/

preserve

keep folioviv foliohog w1- w12 factor p1- lnexp exp note

save "$data_pro//data_for_estimation.dta", replace 

restore

/** NOW RECALCULATING SHARES AND TOTAL EXPENDITURE DUE TO UNDER-RECORDING **/

	egen totalspend = sum(exp*factor)

foreach X of numlist 1(1)12 {

	egen totalspend`X' = sum(spend`X'*factor)
	gen totalshare`X' = (totalspend`X'/totalspend)*100

}

gen id = 1
sort id
merge id using "$processed_data\\weights_cat1.dta"

tab _merge
keep if _merge==3
drop _merge 

foreach X of numlist 1(1)12 {

	replace spend`X' = spend`X'*re_weight`X'/totalshare`X'
}

	drop exp
	egen exp = rsum(spend1-spend12)

foreach X of numlist 1(1)12 {

	replace w`X' = spend`X'/exp
}

replace exp = exp*2.5

replace lnexp = ln(exp)

preserve

keep folioviv foliohog w1- w12 factor p1- lnexp exp note

save "$data_pro//data_for_estimation1.dta", replace 

restore

exit
