**********************************************
* Program name: create_grossincome.do
* Program purpose: This files calculates gross income using the
* inverted 2008 tax system
* Program created: 5 November 2010, by David Phillips
* Program updated: 6 December 2010, by Laura Abramovsky
* Program updated: 13 December 2012, by David Phillips
**************************************************************************************************

clear all
cap log close
set mem 200m
set more off

cd "W:\Mexico_Fiscal_Reforms2"

global data     "Mexico Raw Data"
global data_pro "Mexico Processed Data"
global dofile "Do Files"

    use "$data\ingresos.dta", clear

    do "$data\\$dofile\\clave_ingresos.do"

    label var folioviv "Residence identifier"

    label var foliohog "Household identifier"

    label var numren "Individual identifier"

    label var clave "monetary and non-monetary income source identifier"

    forvalues x = 1(1)6 {
    label var mes_`x' "Month of reference for monetary income"

    }


    * we will focus on income earned last month, so drop income earned before last month

    drop if inlist(clave_code,20,21,22)

    * drop monthly income variables ing_* mes_*

    drop ing_1 ing_2 ing_3 ing_4 ing_5 ing_6 mes_*

    label var ing_tri "Quarterly income - estimated"


    ***** this is from Hector ISR 2008

    g decena = substr(folioviv,3,1)

    label var decena "referes to the 10 days when the survey was done, used to calculate montly income"

    g double ing_mens = ing_tri / 2.99178 if decena == "1"	/* Calculation of Average Monthly Income */
    replace ing_mens  = ing_tri / 3.02465 if decena == "2"
    replace ing_mens  = ing_tri / 3.02465 if decena == "3"
    replace ing_mens  = ing_tri / 3.02465 if decena == "4"
    replace ing_mens  = ing_tri / 3.00821 if decena == "5"
    replace ing_mens  = ing_tri / 3.00821 if decena == "6"
    replace ing_mens  = ing_tri / 3.00821 if decena == "7"
    replace ing_mens  = ing_tri / 3.02465 if decena == "8"
    replace ing_mens  = ing_tri / 3.02465 if decena == "9"

    label var ing_mens "Monthly income - estimated"


* This do file uses individual level data to calculate gross income for each individual, and to calculate HH level gross income
* This is based on Hector Villarreal code (ISR Simulator)


    ** Net income -- wages and other labour income **

    g double ing_neto = ing_mens if (clave>="P001" & clave<="P009")| clave=="P011"  | clave=="P013" ///
			| clave=="P015" | clave=="P017" | clave=="P018" | clave=="P019" | clave=="P032"	/* Modificado el 30/oct/2009 */

            /* Above includes Income from pensions, which Hector does not include */

			*** Wage income ***
			g double ing_ss = ing_mens if clave=="P001" | clave=="P011" | clave=="P015"			  /* Wages amd salaries */
			g double ing_destajo = ing_mens if clave=="P002"						        /* Piecework */
			g double ing_prop = ing_mens if clave=="P003"							        /* Commissions and tips */
			g double ing_bono = ing_mens if clave=="P006"							        /* Bonus or addtional wages */

            label var ing_ss        "Wages amd salaries"
            label var ing_destajo   "Piecework"
            label var ing_prop      "Commissions and tips"
            label var ing_bono      "Bonus or addtional wages"


			*** Income including exemptions***
			g double ing_horas = ing_mens if clave=="P004"							/* Overtime */
			g double ing_horasgrav = .5*ing_horas if ing_horas<=1138.5735				/* Exemption according to Art. 109 of the current LISR 2008 */
			replace ing_horasgrav = (.5*1138.5735)+ (ing_horas - 1138.5735) if ing_horas>1138.5735

			g double ing_agui = ing_mens if clave=="P009"							/* End-of-the-year bonus*/
			g double ing_aguigrav = ing_agui-131.457 if ing_agui>=131.457 				/* Exemption according to Art. 109 of the current LISR 2008 */
			replace ing_aguigrav = 0 if ing_agui>0 & ing_agui<131.457

			g double ing_grati = ing_mens if clave=="P005"							/* Incentives, rewards and prizes */
			g double ing_gratigrav = ing_grati-131.457 if ing_grati>=131.457				/* Exemption according to Art. 109 of the current LISR 2008 */
			replace ing_gratigrav = 0 if ing_grati>0 & ing_grati<131.457

			g double ing_prima = ing_mens if clave=="P007"							/* Holiday bonuses and allowances in cash */
			g double ing_primagrav = ing_prima-65.73 if ing_prima>=65.73				/* Exemption according to Art. 109 of the current LISR 2008 */
			replace ing_primagrav = 0 if ing_prima>0 & ing_prima<65.73

			g double ing_util1 = ing_mens if clave=="P008"         /* Profit sharing from secondary subordinated work and end-of-the-year bonus */
			g double ing_util1grav = ing_util1-65.73 if ing_util1>=65.73				/* Exemption according to Art. 109 of the current LISR 2008 */
			replace ing_util1grav = 0  if ing_util1>0 & ing_util1<65.73

			g double ing_util2 = ing_mens if clave == "P019"         /* Profit sharing from secondary subordinated work and end-of-the-year bonus */
			g double ing_util2grav = ing_util2-65.73 if ing_util2>=65.73				/* Exemption according to Art. 109 of the current LISR 2008 */
			replace ing_util2grav = 0  if ing_util2>0 & ing_util2<65.73


            g double ing_pens = ing_mens if clave=="P032"                              /* Includes Income from pensions */

			g double ing_otros = ing_mens if clave == "P013" | clave == "P017" | clave == "P018"

    ** Net non-labour income -- many sources **
    gen double ing_nl = ing_mens if (inlist(clave_code,12, 16) | (clave_code>=23&clave_code!=.)) & clave_code!=32


            * Hector collapses using folioviv foliohog numren proyecto, what's proyecto?

			collapse (sum) ing_mens ing_neto ing_ss ing_destajo ing_prop ing_bono ing_horas ing_horasgrav ing_agui ing_aguigrav ing_grati ///
				ing_gratigrav ing_prima ing_primagrav ing_util1 ing_util1grav ing_util2 ing_util2grav ing_otros ing_nl ing_pens, by(folioviv foliohog numren)

		replace ing_otros = ing_otros - ing_util2
		replace ing_otros = 0 if ing_otros<0

		replace ing_util1 = ing_util1 + ing_util2
		replace ing_util1grav = ing_util1grav + ing_util2grav

		drop ing_util2
		rename ing_util1 ing_util
		rename ing_util1grav ing_utilgrav

		sort folioviv foliohog numren

		merge folioviv foliohog numren using "$data_pro\ingresos_mon_net_ad.dta"

		tab _merge

		drop _merge




		* Now need taxable income separately by each component - let us rename them according to the names in the documentation

		gen 	 incnet1 = ing_ss + ing_destajo + ing_prop + ing_bono
		gen    inctax1 = incnet1

		rename ing_horas incnet2
		rename ing_horasgrav inctax2

		rename ing_agui incnet3
		rename ing_aguigrav inctax3

		rename ing_grati incnet4
		rename ing_gratigrav inctax4

		rename ing_prima incnet5
		rename ing_primagrav inctax5

		rename ing_util incnet6
		rename ing_utilgrav inctax6

		gen incnet7 = ing_pens
		rename ing_pens inctax7

		gen incnet8 = ing_otros
		rename ing_otros inctax8

		gen incnet9 = inc_cap
		rename inc_cap inctax9

		gen incnet10 = inc_semp + inc_tran + inc_other + inc_oemp
		rename inc_semp inctax10
		replace inctax10 = incnet10

		label var incnet1 "Net Wages and Salaries"
		label var inctax1 "Taxed Wages and Salaries"
		label var incnet2 "Net Overtime"
		label var inctax2 "Taxed Overtime"
		label var incnet3 "Net End-of-year bonus"
		label var inctax3 "Taxed End-of-year bonus"
		label var incnet4 "Net Incentives, rewards and prizes"
		label var inctax4 "Taxed Incentives, rewards and prizes"
		label var incnet5 "Net Holiday bonuses and cash allowances"
		label var inctax5	"Taxed Holiday bonuses and cash allowances"
		label var incnet6 "Net Profit sharing"
		label var inctax6 "Taxed Profit sharing"
		label var incnet7 "Net Pensions"
		label var inctax7 "Taxed Pensions"
		label var incnet8 "Net other labour"
		label var inctax8 "Taxed other labour"
		label var incnet9 "Net Capital"
		label var inctax9 "Taxed Capital"
		label var incnet10 "Net Other Inc"
		label var inctax10 "Taxed Other inc"

		keep folioviv foliohog numren inc*
		order folioviv foliohog numren incnet1 inctax1 incnet2 inctax2 incnet3 inctax3 incnet4 inctax4 incnet5 inctax5 incnet6 inctax6 incnet7 inctax7 incnet8 inctax8 incnet9 inctax9

		foreach X of numlist 1(1)10 {

			replace incnet`X' = incnet`X'*12
			replace inctax`X' = inctax`X'*12

			gen excen`X' = incnet`X' - inctax`X'

		}

/*************************************************/
/******** NOW STUFF ON INFORMAL/FORMAL ***********/
/*************************************************/

            * merge whether formal or informal and age
            cap drop _merge
            merge (folioviv foliohog numren) using "$data_pro\pobla08.dta", sort uniqmaster keep(inst_1 inst_2 inst_3 inst_4 inscr_1 edad rel_head ss_med_ins)

            tab _merge
            keep if inlist(_m,1,3)
            drop _m

*** Look at some indiv that get more than one coverage, which one do they get through work? important to define which is their soc sec contribution rate
*** This is important to define their gross income and then for the tax simulator.
*** Also CIEP's code does not use whether they have ss through work, and they don't deal with the issue of multiple ss
*** use information in "clas_emp" = 3 is public, from file "trabajos.do" to see if they work for private or public sector
*** see for example

            cap drop _merge
            merge (folioviv foliohog numren) using "$data_pro\trabajos_stateworker.dta", sort uniqmaster keep(state*)
            tab _m
            keep if inlist(_m,1,3)
            drop _m

            gen     formal_w=   1 if (inst_1==1) &inscr_1==1 & state_main==0

                * this below is for individuals that only report to have private insurance, they report to have it through work,
                * but they report to work in the public sector

            replace formal_w=   1 if formal_w==.  & (inst_1==1) &  inscr_1==1 & state_main==1 & inst_2==.&inst_3==.&inst_4==.

            replace formal_w=   2 if formal_w ==. & ((inst_2==2) | (inst_3==3)) &inscr_1==1

            replace formal_w=   3 if formal_w==.  & (inst_4==4)&inscr_1==1

            replace formal_w=   0 if formal_w==.

            label define formal_w 0 "Informal" 1 "IMMS" 2 "ISSSTE" 3 "PEMEX"
            label values formal_w formal_w

            g formal_h = (inst_1==1)
            replace formal_h =2 if ((inst_2==2) | (inst_3==3))
            replace formal_h =3 if (inst_4==4)

            label values formal_h formal_w


            gen adult =1 if edad>=12

/******************************************************/
/******** NOW ALLOCATING PEOPLE TO INFORMAL ***********/
/******************************************************/

		foreach X of numlist 1(1)10 {

			local Y = `X'+10

			gen inc`Y' = 0

			replace inc`Y' = incnet`X' if formal_w==0
			replace incnet`X' = 0 if formal_w==0
			replace inctax`X' = 0 if formal_w==0

		}

/*************************************************************/
/******** NOW MAKING SURE ALL FORMAL PAID MIN WAGE ***********/
/*************************************************************/

*** Imputation of minimum wage. See Methodological Annex***
*** Increase the wages and salaries component to be equal to an (annual) minimum wage? ***

replace incnet1 = 22661.9404 if incnet1>0 & incnet1< 22661.9404 & formal_w == 1
replace inctax1 = 22661.9404 if inctax1>0 & inctax1< 22661.9404 & formal_w == 1

replace incnet1 = 21481.4264 if incnet1>0 & incnet1< 21481.4264 & (formal_w == 2 | formal_w == 3)
replace inctax1 = 21481.4264 if inctax1>0 & inctax1< 21481.4264 & (formal_w == 2 | formal_w == 3)

egen ing_gravado = rsum(inctax1 inctax2 inctax3 inctax4 inctax5 inctax6 inctax8)

replace incnet1 = 22661.9404 - ing_gravado if incnet1==0 & ing_gravado< 22661.9404 & ing_gravado> 0 &  formal_w == 1
replace inctax1 = 22661.9404 - ing_gravado if inctax1==0 & ing_gravado< 22661.9404 & ing_gravado> 0 & formal_w == 1

replace incnet1 = 21481.4264 - ing_gravado if incnet1==0 & ing_gravado< 21481.4264 & ing_gravado> 0 & (formal_w == 2 | formal_w == 3)
replace inctax1 = 21481.4264 - ing_gravado if inctax1==0 & ing_gravado< 21481.4264 & ing_gravado> 0 & (formal_w == 2 | formal_w == 3)

drop ing_gravado
egen ing_gravado = rsum(inctax1 inctax2 inctax3 inctax4 inctax5 inctax6 inctax8)


/********************************************************/
/******** BACK TO THE GROSS INCOME CALCULATOR ***********/
/********************************************************/
    /*

    note: this dataset is at the [ residence (folioviv) - household (foliohog) - individual (numren)] level
    note: combines information from ingresos file and pobla08 to define formal workers, ///
    and Hector Villarreal (CEFP) codes to categorise income sources according to the Income Tax system (ISR)
    note: All income variables are monthly figures unless it says annual; and labour income unless it says non labour income
    note: source is ENEIGH 2008

    */

/***** CONTINUE *****/

*** Get Gross Income from 2008. The matrices ISR_IO and ISR_MO reflect the tax system described in the Income Tax Law 2008 (LSIR 2008) ///
***                                                        according to the income brackets for the ISSSTE and IMSS, respectively ***

*** THIS IS THE TAX SCHEDULE FOR 2008 AND IS USED TO CONVERT FROM NET TO GROSS ***

*			Tasa_ISR	Cuota_ISR	Crdito	Tasa_ISSSTE	Cuota_ISSSTE	Inferior	Superior	Inferior_ISR
matrix ISR_I0 =  (1.92,		0.00,		4884.24,	8.525,	0.00,			0.01,		5952.84,	.01\		/*
		*/	6.40,		114.24,	4884.24,	8.525,	0.00,			5952.85,	21227.52,	5952.85\	/*
		*/	6.40,		114.24,	4881.96,	8.525,	0.00,			21227.53,	31840.56,	5952.85\	/*
		*/	6.40,		114.24,	4879.44,	8.525,	0.00,			31840.57,	41674.08,	5952.85\	/*
		*/	6.40,		114.24,	4713.24,	8.525,	0.00,			41674.09,	42454.44,	5952.85\	/*
		*/	6.40,		114.24,	4713.24,	8.525,	0.00,			42454.45,	50524.92,	5952.85\	/*
		*/	10.88,	2966.76,	4589.52,	8.525,	0.00,			50524.93,	53353.80,	50524.93\	/*
		*/	10.88,	2966.76,	4250.76,	8.525,	0.00,			53353.81,	56606.16,	50524.93\	/*
		*/	10.88,	2966.76,	3898.44,	8.525,	0.00,			56606.17,	64025.04,	50524.93\	/*
		*/	10.88,	2966.76,	3535.56,	8.525,	0.00,			64025.05,	74696.04,	50524.93\	/*
		*/	10.88,	2966.76,	3042.48,	8.525,	0.00,			74696.05,	85366.80,	50524.93\	/*
		*/	10.88,	2966.76,	2611.32,	8.525,	0.00,			85366.81,	88587.96,	50524.93\	/*
		*/	10.88,	2966.76,	0.00,		8.525,	0.00,			88587.97,	88793.04,	50524.93\	/*
		*/	16.00,	7130.88,	0.00,		8.525,	0.00,			88793.05,	103218.00,	88793.05\	/*
		*/	17.92,	9438.60,	0.00,		8.525,	0.00,			103218.01,	123580.20,	103218.01\	/*
		*/	19.94,	13087.44,	0.00,		8.525,	0.00,			123580.21,	191953.50,	123580.21\	/*
		*/	19.94,	13087.44,	0.00,		0.00,		16364.036,		191953.51,	249243.48,	123580.21\	/*
		*/	21.95,	38139.60,	0.00,		0.00,		16364.036,		249243.49,	392841.96,	249243.49\	/*
		*/	28.00,	69662.40,	0.00,		0.00,		16364.036,		392841.97,	1000000000,	392841.97)

*			Tasa_ISR	Cuota_ISR	Crdito	Tasa_IMSS	Cuota_IMSS	Inferior	Superior	Inferior_ISR
matrix ISR_M0 =  (1.92,		0.00,		4884.24,	2.375,	0.00,		0.01,		5952.84,	0.01\	/*
		*/	6.40,		114.24,	4884.24,	2.375,	0.00,		5952.85,	21227.52,	5952.85\	/*
		*/	6.40,		114.24,	4881.96,	2.375,	0.00,		21227.53,	31840.56,	5952.85\	/*
		*/	6.40,		114.24,	4879.44,	2.375,	0.00,		31840.57,	41674.08,	5952.85\	/*
		*/	6.40,		114.24,	4713.24,	2.375,	0.00,		41674.09,	42454.44,	5952.85\	/*
		*/	6.40,		114.24,	4713.24,	2.375,	0.00,		42454.45,	50524.92,	5952.85\	/*
		*/	10.88,	2966.76,	4589.52,	2.375,	0.00,		50524.93,	53353.8,	50524.93\	/*
		*/	10.88,	2966.76,	4250.76,	2.375,	0.00,		53353.81,	56606.16,	50524.93\	/*
		*/	10.88,	2966.76,	3898.44,	2.375,	0.00,		56606.17,	57586.05,	50524.93\	/*
		*/	10.88,	2966.76,	3898.44,	2.775,	230.3442,	57586.06,	64025.04,	50524.93\	/*
		*/	10.88,	2966.76,	3535.56,	2.775,	230.3442,	64025.05,	74696.04,	50524.93\	/*
		*/	10.88,	2966.76,	3042.48,	2.775,	230.3442,	74696.05,	85366.8,	50524.93\	/*
		*/	10.88,	2966.76,	2611.32,	2.775,	230.3442,	85366.81,	88587.96,	50524.93\	/*
		*/	10.88,	2966.76,	0.00,		2.775,	230.3442,	88587.97,	88793.04,	50524.93\	/*
		*/	16.00,	7130.88,	0.00,		2.775,	230.3442,	88793.05,	103218,	88793.05\	/*
		*/	17.92,	9438.60,	0.00,		2.775,	230.3442,	103218.01,	123580.2,	103218.01\	/*
		*/	19.94,	13087.44,	0.00,		2.775,	230.3442,	123580.21,	249243.48,	123580.21\	/*
		*/	21.95,	38139.60,	0.00,		2.775,	230.3442,	249243.49,	392841.96,	249243.49\	/*
		*/	28.00,	69662.40,	0.00,		2.775,	230.3442,	392841.97,	479883.75,	392841.97\	/*
		*/	28.00,	69662.40,	0.00,		0.00,		13206.401,	479883.76,	1000000000,	392841.97)

*******************************************************************************************************************
********** DSP ****************************************************************************************************

** gravable = taxable (i.e. gross - exemption)
** gravado = taxed income ( gross - tax (+ exemption?)) (or min wage if thats higher than net income)
** so the "ing_gravable" bit calculates taxable income from the net income and the rates and amounts schedule above

/* calculation seems to work as follows:

- taxable_income= (net income + ISR_quota - (ISR_rate*ISR_minamountforrate) - TaxCredit+ SocSec_quota) / (1 - ISR_Rate - SocSecRate)
- inc tax_amount = ISR_quota+ ISR_rate*(taxable_income - minamountforrate) -  TaxCredit
- social_security = SOC_rate*taxable_income + SOC_quota (is this correct!?!)
- categ = put people into category if their taxable income is between Inferior and Superior (min and max)
- prueba = test = taxable - net_of_tax - soc_sec - inc_tax  ---- should equal zero!

*/

*******************************************************************************************************************
********** DSP ****************************************************************************************************


*** THE FIRST STEP IS TO CALCULATE THE OVERALL TAXABLE INCOME TO SEE HOW MUCH CREDIT THAT PERSON HAS ***
*** I THEN SUBTRACT THAT CREDIT FROM THE FIRST COMPONENT OF INCOME THEY HAVE ***
*** AND IGNORE THE CREDIT ELEMENT FROM THE CALCULATION OF TAXABLE INCOME FOR EACH OF THE OTHER COMPONENTS ***

*************************************************************************
*** FIRST UP IS THE OVERALL TAXABLE INCOME USING OVERALL TAXED INCOME ***
*************************************************************************

gen double ing_gravable = .
gen double isr = .
gen double prueba = .
gen double categ = .
gen double cuotas = .
gen double taxcred = .

forvalues j=1(1)19 {
	replace ing_gravable = (ing_gravado+ISR_I0[`j',2]-((ISR_I0[`j',1]/100)*ISR_I0[`j',8])-ISR_I0[`j',3]+ISR_I0[`j',5])/((1-ISR_I0[`j',4]/100)-(ISR_I0[`j',1]/100)) if (categ == . & ing_gravado != . & ing_gravado != 0) & (formal_w==2 | formal_w==3)
	replace isr = ISR_I0[`j',2]+(ISR_I0[`j',1]/100)*(ing_gravable-ISR_I0[`j',8])-ISR_I0[`j',3] if (categ ==. & ing_gravado !=. & ing_gravado !=0) & (formal_w==2 | formal_w==3)
	replace cuotas = (ISR_I0[`j',4]/100)*ing_gravable+ISR_I0[`j',5] if (categ ==. & ing_gravado !=. & ing_gravado !=0 ) & (formal_w==2 | formal_w==3)
	replace categ = `j' if (ing_gravable>=ISR_I0[`j',6] & ing_gravable<=ISR_I0[`j',7]) & (formal_w==2 | formal_w==3)
	replace taxcred = ISR_I0[`j',3] if categ == `j' & (formal_w==2 | formal_w==3)
	replace prueba = ing_gravable-ing_gravado-cuotas-isr if (categ!=. & ing_gravado !=. & ing_gravado !=0 ) & (formal_w==2 | formal_w==3)
	}

forvalues j=1(1)20 {
	replace ing_gravable = (ing_gravado+ISR_M0[`j',2]-((ISR_M0[`j',1]/100)*ISR_M0[`j',8])-ISR_M0[`j',3]+ISR_M0[`j',5])/((1-ISR_M0[`j',4]/100)-(ISR_M0[`j',1]/100)) if categ ==. & ing_gravado !=. & ing_gravado !=0 & formal_w==1
	replace isr = ISR_M0[`j',2]+(ISR_M0[`j',1]/100)*(ing_gravable-ISR_M0[`j',8])-ISR_M0[`j',3] if categ ==. & ing_gravado !=. & ing_gravado !=0 & formal_w==1
	replace cuotas = (ISR_M0[`j',4]/100)*ing_gravable+ISR_M0[`j',5] if categ==. & ing_gravado !=. & ing_gravado !=0  & formal_w==1
	replace categ = `j' if (ing_gravable >=ISR_M0[`j',6] & ing_gravable <=ISR_M0[`j',7]) & formal_w==1
	replace taxcred = ISR_M0[`j',3] if categ == `j' & (formal_w==1)
	replace prueba = ing_gravable -ing_gravado-cuotas-isr if categ !=. & ing_gravado !=. & ing_gravado !=0 & formal_w==1
	}


gen double tot_toallocate = ing_gravable - ing_gravado
gen double prop_toallocate = tot_toallocate/ing_gravado

foreach X of varlist inctax1 inctax3 inctax4 inctax5 inctax6 inctax8 {

gen gr_`X' = `X'*(prop_toallocate+1)

}

foreach X in 1 3 4 5 6 8 {

gen inc`X' = gr_inctax`X' + excen`X'

}

exit

/*** WE NEED A SPECIAL CASE TO DEAL WITH OVERTIME AS THE EXEMPTION HERE OPERATES AS EXEMPTING A PROPORTION OF THE PAYMENT ***/

gen x = prop_toallocate*inctax2
gen y = x + inctax2
gen inc2 = excen2 + y

** first is the prop_toallocate is positive

replace inc2 = inc2 + x if (inc2+x)< 1138.5735*12 & x > 0
replace inc2 = inc2 + (1138.5735*12 - inc2) if (inc2+x)>= 1138.5735*12 & inc2<1138.5735*12 & x > 0

** now what do we do when prop_toallocate is negative

replace inc2 = inc2 + x if incnet2< 1138.5735*12 & x<0
replace inc2 = inc2 + (1138.5735*12 - inc2) if incnet2> 1138.5735*12 & inc2< 1138.5735*12 & x<0

order folioviv foliohog numren inc1 inc2 inc3 inc4 inc5 inc6 inc8

gen inc7 = inctax7
gen inc9 = inctax9
gen inc10 = inctax10

order folioviv foliohog numren inc1 inc2 inc3 inc4 inc5 inc6 inc7 inc8 inc9 inc10 inc11- inc20 formal_w formal_h

foreach X of numlist 1(1)20 {

replace inc`X' = 0 if inc`X'==.

}

replace inc9 = 0 if formal_w==0

order folioviv foliohog numren formal_w inc1 inc2 inc3 inc4 inc5 inc6 inc7 inc8 inc9 inc10 inc11-inc20

keep folioviv foliohog numren formal_w inc1 inc2 inc3 inc4 inc5 inc6 inc7 inc8 inc9 inc10 inc11-inc20

sort folioviv foliohog numren

save "$data_pro\incomes2.dta", replace

exit



********************************************************************************************
*** NET UP IS THE TAXABLE INCOME BY-COMPONENT ASSUMING TAX CREDIT DEDUCTED FROM SALARIES ***
********************************************************************************************

gen ing_1 = inctax1
gen ing_8 = ing_1 + inctax8
gen ing_2 = ing_8 + inctax2
gen ing_3 = ing_2 + inctax3
gen ing_4 = ing_3 + inctax4
gen ing_5 = ing_4 + inctax5
gen ing_6 = ing_5 + inctax6

foreach X in 1 8 2 3 4 5 6 {

gen double ing_gravable_`X' = .

forvalues j=1(1)19 {
	replace ing_gravable_`X' = (ing_`X'+ISR_I0[`j',2]-((ISR_I0[`j',1]/100)*ISR_I0[`j',8]) - taxcred + ISR_I0[`j',5])/((1-ISR_I0[`j',4]/100)-(ISR_I0[`j',1]/100)) if (categ == . & ing_`X' != . & ing_`X' != 0) & (formal_w==2 | formal_w==3)
	}

forvalues j=1(1)20 {
	replace ing_gravable_`X' = (ing_`X'+ISR_M0[`j',2]-((ISR_M0[`j',1]/100)*ISR_M0[`j',8])- taxcred + ISR_M0[`j',5])/((1-ISR_M0[`j',4]/100)-(ISR_M0[`j',1]/100)) if categ ==. & ing_`X' !=. & ing_`X' !=0 & formal_w==1
	}


}

g ingbruto = ing_gravable + exencion if formal_w != 0
replace ingbruto = ing_anual if formal_w == 0


