clear
set mem 500m


/*
THIS FILE CREATES PROCESSED FILES FROM RAW FILES.
THESE INCLUDE LABELS AND ONLY THOSE VARIABLES NEEDED FOR THE FINAL ANALYSIS.
both the distributional analysis and the behavioural analysis

ORDER IS:

POBLA : individual level data
HOGARES : household level data
TRABAJO: individual level data about type of job (useful to look at e.g. informality in the labour market)
INCOME FILE : individual level data
CONSUMPTION FILES : gasto (HH level) ; gastodiario (Indiv - HH level) ; gastoeduca (Indiv - HH level); nomonetario (Indiv - HH level)


Last version updated: 22 November 2010, by Laura Abramovsky
Update: change expenditure category ; G002-G006 and G011 moved from exp6 to exp8
Update: re-define expenditure categories to match demand system; clean program
* Program updated: 13 December 2012, by David Phillips

*/

cd "W:\Mexico_Fiscal_Reforms2"

global data     "Mexico Raw Data"
global data_pro "Mexico Processed Data"
global dofile   "Mexico Raw Data\Do Files"


*****************
/* POBLA FILE */
*****************


    use "$data\pobla08.dta", clear

    keep folioviv foliohog numren parentesco sexo edad asis_esc nivel beca n_instr161 segsoc ss_aa ss_mm segpop atemed inst_* inscr_* trabajo verifica

    label var folioviv "Residence identifier"

    label var foliohog "Household identifier"

    label var numren "Individual identifier"

    label var parentesco "Relationship to Head of Household"

    label var sexo "Sex"
    rename sexo sex

    label var edad "Age"
    rename edad age

    label var n_instr161 "Highest level of qualification attained"
    # delimit ;
    label define n_instr161 0 "Ninguno"
                            1 "Preescolar"
                            2 "Primaria"
                            3 "Secundaria"
                            4 "Preparatoria o bachillerato"
                            5 "Normal"
                            6 "Carrera tcnica o comercial"
                            7 "Profesional"
                            8 "Maestra"
                            9 "Doctorado";
    # delimit cr
    label values n_instr161 n_instr161
    rename n_instr161 education


    * define relationship to the HH head
    gen     rel_head = 1 if parentesco==101
    replace rel_head = 2 if inlist(parentesco, 201, 202, 203, 204)
    replace rel_head = 3 if inlist(parentesco, 301, 302, 303, 304, 305)
    replace rel_head = 4 if (parentesco>=401&parentesco<=461)|parentesco==999
    replace rel_head = 5 if parentesco>=501&parentesco<=503
    replace rel_head = 6 if parentesco>=601&parentesco<999

    label var rel_head "relationship to the HH head"

    label define rel_head 1 "Head" 2 "Head spouse" 3 "Children" 4 "Employee" 5 "Not related" 6 "Other relative"
    label values rel_head rel_head

    * define whether social security medical insurance

    label var inst_1 "social security: IMMS"
    label var inst_2 "social security: ISSSTE"
    label var inst_3 "social security: State ISSSTE"
    label var inst_4 "social security: PEMEX"
    label var inst_5 "social security: Other"

    gen ss_med_ins=(inst_1==1|inst_2==2|inst_3==3|inst_4==4)
    label var ss_med_ins "medical insurance through social security"

    label var inscr_1 "Medical insurance: through work"
    label var inscr_2 "Medical insurance: through retirement or disability scheme"
    label var inscr_3 "Medical insurance: through relative in HH"
    label var inscr_4 "Medical insurance: through death of the insured" /*is this correct?*/
    label var inscr_5 "Medical insurance: through student scheme"
    label var inscr_6 "Medical insurance: self-employed"
    label var inscr_7 "Medical insurance: through relative in other HH"
    label var inscr_8 "Medical insurance: through doesn't know"

    label var trabajo "worked in the last month"
    label define trabajo 1 "Yes" 2 "No"
    label values trabajo trabajo

    label var verifica "checked those trabajo=2, in fact didn't work verifica=6"

    gen     trabajo_2=1 if (trabajo==1)
    replace trabajo_2=1 if inlist(verifica,1,2,3,4,5)
    replace trabajo_2=2 if (verifica==6&trabajo==2)
    label var trabajo_2 "worked in the last month, includes verifica"
    label values trabajo_2 trabajo

    * define formal worker: whether medical insurance through social security and through work

    gen formal_w=ss_med_ins==1&inscr_1==1
    label var formal_w "formal worker: med ins through work soc sec"

        ** this is still not very clear, I have many individuals that report to get ss through work but report not to be working?
        tab formal trabajo_2, mi

    rename trabajo_2 empstat
    replace empstat = 0 if empstat!=1



    keep    folioviv foliohog numren rel_head sex age education empstat inst_* inscr_1 ss_med_ins  parentesco
    order   folioviv foliohog numren rel_head sex age education empstat inst_* inscr_1 ss_med_ins  parentesco
    sort folioviv foliohog numren

    save "$data_pro\pobla08.dta", replace


    * generate hhtype & numfams
    ***************************

    gen temp=1 if parentesco==101
    egen numhead=sum(temp), by(folioviv foliohog)
    drop temp

    gen temp=1 if parentesco>=200&parentesco<300
    egen numspouse=sum(temp), by(folioviv foliohog)
    drop temp

    gen temp=1 if age<18 & parentesco>=300&parentesco<400
    egen numchild=sum(temp), by(folioviv foliohog)
    drop temp

    gen temp=1 if age>=18 & parentesco>=300&parentesco<400
    egen numadult_child=sum(temp), by(folioviv foliohog)
    drop temp

    gen temp=1 if parentesco>=400&parentesco<=413
    egen numdomper=sum(temp), by(folioviv foliohog)
    drop temp

    gen temp=1 if parentesco>=421&parentesco<=461
    egen numdomperrel=sum(temp), by(folioviv foliohog)
    drop temp

    gen temp=1 if parentesco==501
    egen numnonrel=sum(temp), by(folioviv foliohog)
    drop temp

    gen temp=1 if parentesco>=502&parentesco<600
    egen numtutor=sum(temp), by(folioviv foliohog)
    drop temp

    gen temp=1 if parentesco>=600&parentesco<700
    egen numotherrel=sum(temp), by(folioviv foliohog)
    drop temp

    gen temp=1 if parentesco>=700&parentesco<999
    egen numguest=sum(temp), by(folioviv foliohog)
    drop temp

    gen temp=1 if age>=64
    egen numpens=sum(temp), by(folioviv foliohog)
    drop temp

    gen temp = age if parentesco==101
    egen edad_head=sum(temp), by(folioviv foliohog)
    drop temp

    drop numren
    collapse (mean) edad_head num*, by(folioviv foliohog)

    gen  double hhtype = 1 if edad_head<64 & numspouse>0  & numchild==0 & numadult_child==0 & numdomper==0 & numdomperrel==0 & numtutor==0 & numguest==0 & numnonrel==0 & numotherrel==0
    replace     hhtype = 2 if edad_head<64 & numspouse==0 & numchild==0 & numadult_child==0 & numdomper==0 & numdomperrel==0 & numtutor==0 & numguest==0 & numnonrel==0 & numotherrel==0
    replace     hhtype = 3 if edad_head<64 & numspouse>0  & numchild>0  & numadult_child==0 & numdomper==0 & numdomperrel==0 & numtutor==0 & numguest==0 & numnonrel==0 & numotherrel==0
    replace     hhtype = 4 if edad_head<64 & numspouse==0 & numchild>0  & numadult_child==0 & numdomper==0 & numdomperrel==0 & numtutor==0 & numguest==0 & numnonrel==0 & numotherrel==0
    replace     hhtype = 5 if edad_head>=64 & numspouse>0   & numchild==0 & numadult_child==0 & numdomper==0 & numdomperrel==0 & numtutor==0 & numguest==0 & numnonrel==0 & numotherrel==0
    replace     hhtype = 6 if edad_head>=64 & numspouse==0  & numchild==0 & numadult_child==0 & numdomper==0 & numdomperrel==0 & numtutor==0 & numguest==0 & numnonrel==0 & numotherrel==0
    replace     hhtype = 7 if hhtype==.    & numchild==0                     & numdomper==0 & numdomperrel==0 & numtutor==0 & numguest==0 & numnonrel==0
    replace     hhtype = 8 if hhtype==.    & numchild>0                      & numdomper==0 & numdomperrel==0 & numtutor==0 & numguest==0 & numnonrel==0
    replace     hhtype = 9 if hhtype==.    & numchild==0
    replace     hhtype = 10 if hhtype==.    & numchild>0

    label define hhtype 1 "couple" 2 "single" 3 "couple children under 18" 4 "single children under 18" 5 "head pensioner, couple" 6 "head pensioner, single" 7 "other family no children under 18" 8 "other family children under 18" 9 "multifamily no children under 18" 10 "multifamily  children under 18"
    label values hhtype hhtype

    egen temp=rsum(numdomper numtutor numguest numnonrel)

    gen     numfam=1
    replace numfam=1+temp if temp>0

    drop temp

    sort folioviv foliohog
    save "$data_pro\hhtype.dta", replace


*************
/* HOGARES */
*************

    use "$data\hogares.dta", clear

    keep folioviv foliohog ten27 estim31 estim32 estim31tri estim32tri residentes hogares2 hogares3 habito consumo negcua est_alim est_trans factor estrato ubica_geo conapo est_dis upm

    label var folioviv folioviv
    label var foliohog foliohog

    label var ten27 "House tenure"

    gen estim32mon= estim32tri/3

    label var estim32mon "Estimated Rent Monthly"

    label var residentes "No of Members in the HH"

    label var hogares2 "Do you share food with everyone in the residence?"

    label var hogares3 "No of households in the residence who purchase food separately"

    label var habito "Frequency of food purchase"
    note habito: values for this variable can be a combination of the following options: 1 "monthly"; 2 "every 15 days"; 3 "every 8 days"; 4 "every 3 days"; 5 "daily"; 6 "other" (e.g. 3 or 5 or 35 meaning every 8 days and daily or 2356)

    label var consumo "Food purchase on same day as day on which food expend info was given?"
    label define consumo 1 "Yes" 2 "No"
    label values consumo consumo

    label var factor "Sample weight"

    label var estrato "Stratum"

    label var ubica_geo "Area Identifier"

    label var conapo "Index of marginalisation"

    label var est_dis "sample stratum"

    label var upm "primary sampling unit"

    label var negcua "At least 1 HH Member owns a shop that sells food, drink and tobacco or provides related services?"
    label values negcua consumo

    label var est_alim "Estimated monthly expenditure in food, drinks and tobaco consumed within and away the HH"

    label var est_trans "Estimated monthly expenditure on public transport"

    preserve

    * generate non monetary income as calculate by estimated rent
    *************************************************************

    collapse (sum) estim32mon estim32tri, by(folioviv foliohog)

    rename estim32mon irent
    label var irent "Monthly estimated imputed rent"
    replace irent=0 if irent<0

    keep folioviv foliohog irent
    sort folioviv foliohog

    save "$data_pro\irent.dta", replace

    restore

    sort folioviv foliohog

    save "$data_pro\hogares.dta", replace


*************
/* TRABAJO */
*************

    //I think only for those that answered trabajo=1 or verifica=1to5 in POBLA, 50672 indiv
    //sample size 50563 unique numrem, sample bigger since some people more than 2 jobs

    use "$data\trabajos.dta", clear

    keep folioviv foliohog numren numtrab trapais subor indep personal trab_* pago contrato tipocontr htrab cmo scian  clas_emp

    label var folioviv "Residence identifier"

    label var foliohog "Household identifier"

    label var numren "Individual identifier"

    label var numtrab "main or secondary job"
    label define numtrab 1 "Main Job" 2 "Secondary Job"
    label values numtrab numtrab

    label var subor "whether employee"

    label var indep "whether self-employed if not employee"

    label var personal "if self-employed, worked with other people?"

    label var pago "remunerated job"
    label define pago 1 "yes" 2 "no, job in hh business" 3 "no, job in non-hh business"
    label values pago pago

    label var contrato "written contract"

    label var tipocontr "contract permanent or not"
    label define tipocontr 1 "temporary" 2 "permanent" 3 "dk"
    label values tipocontr tipocontr

    label var htrab "hours worked"

    label var cmo "occupation code - Mexican Classification of Occupations"

    label var scian "industrial classification"

    label var clas_emp  "type of firm"
    label define clas_emp 1 "stand-alone or family-run" 2 "private sector firm" 3 "state-owned inst" 4 "inst not owned by government"
    label values clas_emp clas_emp

    sort folioviv foliohog numren

    save "$data_pro\trabajos.dta", replace


    * this is to classify formal workers into each contribution category

    gen temp =clas_emp==3&numtrab==1
    egen state_main=max(temp), by(folioviv foliohog numren)
    drop temp
    gen temp = clas_emp==3&numtrab==2
    egen state_sec=max(temp), by(folioviv foliohog numren)
    drop temp
    label var state_main "main job in a state-owned instit"
    label var state_sec "sec job in a state-owned instit"

    keep if numtrab==1
    keep state* folioviv foliohog numren
    sort folioviv foliohog numren
    save "$data_pro\trabajos_stateworker.dta", replace



*************
/* INGRESOS */
*************

    // use Villarreal and Urzua and Absalon 2009 for a description of how income is taxed

    use "$data\ingresos.dta", clear

    do "$dofile\clave_ingresos.do"

    label var folioviv "Residence identifier"

    label var foliohog "Household identifier"

    label var numren "Individual identifier"

    label var clave "monetary and non-monetary income source identifier"

    forvalues x = 1(1)6 {
    label var mes_`x' "Month of reference for monetary income"

    }

    * drop monthly income variables ing_* mes_*

    drop ing_1 ing_2 ing_3 ing_4 ing_5 ing_6 mes_*

    label var ing_tri "Quarterly income - estimated"

    ***** this is from Hector ISR 2008
    g decena = substr(folioviv,3,1)
    label var decena "referes to the 10 days when the survey was done, used to calculate montly income"

    g double ing_mens = ing_tri / 2.99178 if decena == "1"	/* Calculation of Average Monthly Income */
    replace ing_mens  = ing_tri / 3.02465 if decena == "2"
    replace ing_mens  = ing_tri / 3.02465 if decena == "3"
    replace ing_mens  = ing_tri / 3.02465 if decena == "4"
    replace ing_mens  = ing_tri / 3.00821 if decena == "5"
    replace ing_mens  = ing_tri / 3.00821 if decena == "6"
    replace ing_mens  = ing_tri / 3.00821 if decena == "7"
    replace ing_mens  = ing_tri / 3.02465 if decena == "8"
    replace ing_mens  = ing_tri / 3.02465 if decena == "9"

    label var ing_mens "Monthly income - estimated"

    ** Net income -- many sources **
    ********************************

    ** see check_income_sources.do to see that P019 seems to be included in P018

    ** Net employment income -- wages and other employment income
    g double inc_emp = ing_mens if (clave>="P001" & clave<="P009")| clave=="P011"  | clave=="P013" ///
			| clave=="P015" | clave=="P017" | clave=="P018" 	/* Modificado el 30/oct/2009 */

                /* Above includes Income from pensions, which Hector does not include */
                /* It does not include clave=="P019", bcs we think it is included in P018 */

    ** Net self-employment income
    g double inc_semp = ing_mens if (clave>="P067" & clave<="P080")

    ** Net property/capital income
    g double inc_cap = ing_mens if clave=="P012"|clave=="P016"|(clave>="P023"&clave<="P031")|clave=="P065"

    ** Net transfers income
    g double inc_tran = ing_mens if (clave>="P033"&clave<="P045")|clave=="P066" | clave=="P032"

    ** Net other employment income
    g double inc_oemp = ing_mens if (clave>="P020"&clave<="P022")|clave=="P063"|clave=="P064"

    ** Net other income
    g double inc_other = ing_mens if clave=="P046"

    ** Net non-current monetary income (these are not income flows, but are derived from sales of assets and other lump sum gains)
    g double inc_mgains = ing_mens if (clave>="P048"&clave<="P062")

    sort folioviv foliohog numren

    save "$data_pro\ingresos_mon_net.dta", replace


    ** GENERATE AGGREGATE INDIVIDUAL NET INCOME

    collapse (sum) inc_*, by(folioviv foliohog numren)

	label var inc_emp   "Monetary Monthly Employment Income"
    label var inc_semp  "Monetary Monthly Self-Employment Income"
    label var inc_cap   "Monetary Montly Capital Income"
    label var inc_tran  "Monetary Montly Transfers Income"
    label var inc_oemp  "Monetary Montly Other Employment Income"
    label var inc_other "Monetary Monthly Other Income"
    label var inc_mgains "Monetary Monthly Capital Gains"

    keep folioviv foliohog numren    inc_*
    sort folioviv foliohog numren

    save "$data_pro\ingresos_mon_net_ad.dta", replace

    ** GENERATE AGGREGATE HOUSEHOLD NET INCOME

    collapse (sum) inc_*, by(folioviv foliohog)

	label var inc_emp   "Monetary Monthly Employment Income"
    label var inc_semp  "Monetary Monthly Self-Employment Income"
    label var inc_cap   "Monetary Montly Capital Income"
    label var inc_tran  "Monetary Montly Transfers Income"
    label var inc_oemp  "Monetary Montly Other Employment Income"
    label var inc_other "Monetary Monthly Other Income"
    label var inc_mgains "Monetary Monthly Capital Gains"

    keep folioviv foliohog     inc_*
    sort folioviv foliohog

    save "$data_pro\ingresos_mon_net_agg.dta", replace


*-------------------
* EXPENDITURE files
*-------------------

*************
/* GASTO */
*************

    use "Mexico Raw Data\gastos.dta", clear

    *drop some variables we won't use
    drop inmujer enganche contado


    * drop G001 "Own house"
    drop if clave=="G001"

    label var folioviv "Residence identifier"

    label var foliohog "Household identifier"

    label var clave "code identifying type of expenditure"

    label var costo "Total cost/Price paid"
    * this is missing most of the times

    label var lug_com "Type of shop"

    gen informal    =1 if inlist(lug_com, 1,2,3)
    replace informal=0 if informal==.
    label var informal "purchased from informal vendor"

    * not sure what's the difference between inst1 & inst2 yet
    label var inst1 "Type of institution providing health services/goods"
    label var inst2 "Type of institution providing health services/goods"


    label  var fpago "Payment method"
    label define fpago 1 "cash" 2 "credit card" 3 "trade credit" 12 "cash & credit" 21 "cash & credit"  31 "cash and trade credit" 13 "cash and trade credit" 23 "credit card and trade credit" 32 "credit card and trade credit"
    label values fpago fpago


    label var gasto "expenditure"
    label var gasto "expenditure last month"
    label var gas_tri "quarterly expenditure, decena taken into account"

    gen gas_mon=gas_tri/3
    label var gas_mon "montly expenditure, from gas_tri"

    * Classify goods and services according to whether they are VAT taxable or not
    * Use Hector Villarreal's code

    **_m==2 are: food, public transport, included in gastodiario; education expenditure included in gastoeduca;
    **these are not in the description of the codes in pdf files: G023-G030 codes probably related to property services ; and some random N017 & N018

    **there are some codes that are not classified by Hector, corresponding to : H120-H136
    **these correspond to "Maintenance, repair and shoe accessories; Accessories and personal effects; Other"

    **there are a some codes that are in Hector file but that have not been classified N011-N016, and correspond to a v specific type of expenditure
    **including transfers to family abroad, charity donations, expenditure on getting public documents such as a driving license or a passport

    sort clave
    merge clave using "W:\Mexico_Fiscal_Reforms2\Hector's Model\clave e iva_sortclave.dta"

    drop if _m==2

    replace iva="Exento" if iva=="Exentos"
    replace iva="Tasa Cero" if iva=="Tasa cero"

    generate vat=1 if iva=="Exento"
    replace  vat=2 if iva=="Tasa Cero"
    replace  vat=3 if iva=="Gravado"

    label define vat 1 "Exempt" 2 "Zero rate" 3 "Taxed"
    label values vat vat

    ** generate expenditure categories
    gen clave_letter=substr(clave, 1,1)

     ** generate expenditure categories 1-40

    gen     expnum="exp1"                           if (inlist(clave, "J001", "J004", "J005", "J007", "J008") | inlist(clave, "J013", "J016", "J017", "J018", "J036", "J039", "J062", "J072")) & informal==0
    replace expnum="exp31"                          if (inlist(clave, "J001", "J004", "J005", "J007", "J008") | inlist(clave, "J013", "J016", "J017", "J018", "J036", "J039", "J062", "J072")) & informal==1

    replace expnum="exp2"                           if ((clave>="E001"&clave<="E008") | inlist(clave, "E015", "E017", "T905")) & informal==0
    replace expnum="exp32"                          if ((clave>="E001"&clave<="E008") | inlist(clave, "E015", "E017", "T905")) & informal==1

    replace expnum="exp3"                           if inlist(clave, "E029") & informal==0
    replace expnum="exp33"                          if inlist(clave, "E029") & informal==1

    replace expnum="exp4"                           if ((clave>="B001"&clave<="B007") | inlist(clave, "E013", "M001", "T902")) & informal==0
    replace expnum="exp34"                          if ((clave>="B001"&clave<="B007") | inlist(clave, "E013", "M001", "T902")) & informal==1

    replace expnum="exp5"                           if ((clave>="G002"&clave<="G006") | inlist(clave, "G011", "N006", "N007") | (clave>="N011"&clave<="N016")) & informal==0
    replace expnum="exp35"                          if ((clave>="G002"&clave<="G006") | inlist(clave, "G011", "N006", "N007") | (clave>="N011"&clave<="N016")) & informal==1

    replace expnum="exp6"                           if ((clave>="E020"&clave<="E022") | inlist(clave, "E026")) & informal==0
    replace expnum="exp36"                          if ((clave>="E020"&clave<="E022") | inlist(clave, "E026")) & informal==1

    replace expnum="exp7"                           if ((clave>="G011"&clave<="G019")) & informal==0
    replace expnum="exp37"                          if ((clave>="G011"&clave<="G019")) & informal==1

    replace expnum="exp9"                           if inlist(clave, "E014") & informal==0
    replace expnum="exp39"                          if inlist(clave, "E014") & informal==1

    replace expnum="exp10"                          if inlist(clave, "G007") & informal==0
    replace expnum="exp40"                          if inlist(clave, "G007") & informal==1

    replace expnum="exp11"                          if inlist(clave, "L029") & informal==0
    replace expnum="exp41"                          if inlist(clave, "L029") & informal==1

    replace expnum="exp12"                          if (inlist(clave, "J009", "J010", "J014")|(clave>="J020"&clave<="J035") | inlist(clave, "J037", "J038", "J042")|(clave>="J040"&clave<="J059")| inlist(clave, "J063", "J064", "T910")) & informal==0
    replace expnum="exp42"                          if (inlist(clave, "J009", "J010", "J014")|(clave>="J020"&clave<="J035") | inlist(clave, "J037", "J038", "J042")|(clave>="J040"&clave<="J059")| inlist(clave, "J063", "J064", "T910")) & informal==1

    replace expnum="exp13"                          if inlist(clave, "J061") & informal==0
    replace expnum="exp43"                          if inlist(clave, "J061") & informal==1

    replace expnum="exp15"                         if ((clave>="A198"&clave<="A202") | (clave>="A219"&clave<="A222") |(clave>="A243"&clave<="A247") |inlist(clave, "T901")) & informal==0
    replace expnum="exp45"                         if ((clave>="A198"&clave<="A202") | (clave>="A219"&clave<="A222") |(clave>="A243"&clave<="A247") |inlist(clave, "T901")) & informal==1

    replace expnum="exp16"                         if ((clave>="C001"&clave<="C024") | inlist(clave, "T903") |(clave>="G008"&clave<="G010") |(clave>="G020"&clave<="G022")|inlist(clave, "T909", "F007", "T911") |(clave>="I001"&clave<="I026")|(clave>="K001"&clave<="K044")|(clave>="L001"&clave<="L022")  |inlist(clave, "T907")) & informal==0
    replace expnum="exp46"                         if ((clave>="C001"&clave<="C024") | inlist(clave, "T903") |(clave>="G008"&clave<="G010") |(clave>="G020"&clave<="G022")|inlist(clave, "T909", "F007", "T911") |(clave>="I001"&clave<="I026")|(clave>="K001"&clave<="K044")|(clave>="L001"&clave<="L022")  |inlist(clave, "T907")) & informal==1

    replace expnum="exp17"                         if ((clave>="D001"&clave<="D026") | inlist(clave, "T904", "E016", "E018", "E019")) & informal==0
    replace expnum="exp47"                         if ((clave>="D001"&clave<="D026") | inlist(clave, "T904", "E016", "E018", "E019")) & informal==1

    replace expnum="exp18"                         if ((clave>="E009"&clave<="E012") | clave=="M005" |clave=="T915" |(clave>="M007"&clave<="M011")|(clave>="N008"&clave<="N010")) & informal==0
    replace expnum="exp48"                         if ((clave>="E009"&clave<="E012") | clave=="M005" |clave=="T915" |(clave>="M007"&clave<="M011")|(clave>="N008"&clave<="N010")) & informal==1

    replace expnum="exp19"                         if ((clave>="E023"&clave<="E025") | inlist(clave, "E027", "E028", "T912")|(clave>="E030"&clave<="E033")|(clave>="L023"&clave<="L028")|(clave>="N003"&clave<="N005")) & informal==0
    replace expnum="exp49"                         if ((clave>="E023"&clave<="E025") | inlist(clave, "E027", "E028", "T912")|(clave>="E030"&clave<="E033")|(clave>="L023"&clave<="L028")|(clave>="N003"&clave<="N005")) & informal==1

    replace expnum="exp20"                         if ((clave>="F013"&clave<="F017") | inlist(clave, "T906", "T913", "M006")|(clave>="M002"&clave<="M004")|(clave>="M012"&clave<="M018")) & informal==0
    replace expnum="exp50"                         if ((clave>="F013"&clave<="F017") | inlist(clave, "T906", "T913", "M006")|(clave>="M002"&clave<="M004")|(clave>="M012"&clave<="M018")) & informal==1

    replace expnum="exp21"                         if ((clave>="H001"&clave<="H136") | inlist(clave, "T908")) & informal==0
    replace expnum="exp51"                         if ((clave>="H001"&clave<="H136") | inlist(clave, "T908")) & informal==1

    replace expnum="exp22"                         if ((clave>="N001"&clave<="N002") | inlist(clave, "T914")) & informal==0
    replace expnum="exp52"                         if ((clave>="N001"&clave<="N002") | inlist(clave, "T914")) & informal==1

    replace expnum="exp23"                          if (inlist(clave, "J002", "J003", "J006", "J011", "J012") | inlist(clave, "J015", "J019", "J040", "J041", "J043", "J060")|(clave>="J065"&clave<="J071")) & informal==0
    replace expnum="exp53"                          if (inlist(clave, "J002", "J003", "J006", "J011", "J012") | inlist(clave, "J015", "J019", "J040", "J041", "J043", "J060")|(clave>="J065"&clave<="J071")) & informal==1

    replace expnum="exp24"                         if ((clave>="F010"&clave<="F012")) & informal==0
    replace expnum="exp54"                         if ((clave>="F010"&clave<="F012")) & informal==1

    replace expnum="exp25"                          if ((clave>="F001"&clave<="F006") | inlist(clave, "F008", "F009")) & informal==0
    replace expnum="exp45"                          if ((clave>="F001"&clave<="F006") | inlist(clave, "F008", "F009")) & informal==1


    sort folioviv foliohog

    ** save expenditure file with original expenditure categories (clave) at the HH

    save "$data_pro\gastos.dta", replace

    ** NOW DO THE CATEGORIES FOR SPENDING THAT APPEAR IN NATIONAL ACCOUNTS ***

    preserve

	gen exptype = .
	replace exptype = 4 if clave>="C001" & clave<="C019"
	replace exptype = 10 if clave>="C020" & clave<="C022"
	replace exptype = 3 if clave>="C023" & clave<="C024"

	replace exptype = 10 if clave>="D001" & clave<="D026"

	replace exptype = 8 if clave>="E001" & clave<="E019"
	replace exptype = 7 if clave>="E020" & clave<="E033"

	replace exptype = 10 if clave>="F001" & clave<="F009"
	replace exptype = 6 if clave>="F010" & clave<="F017"

	replace exptype = 3 if clave_letter=="G"

	replace exptype = 2 if clave>="H001" & clave<="H136"

	replace exptype = 4 if clave_letter=="I"

	replace exptype = 5 if clave_letter=="J"

	replace exptype = 4 if clave>="K001" & clave<="K036"
	replace exptype = 4 if clave>="K037" & clave<="K044"

	replace exptype = 7 if clave_letter=="L"

	replace exptype = 6 if clave_letter=="M"

	replace exptype = 10 if clave>="N001" & clave<="N002"
	replace exptype = 9 if clave>="N003" & clave<="N005"
	replace exptype = 7 if clave=="N006"
	replace exptype = 10 if clave=="N007"
	replace exptype = 6 if clave=="N008"
	replace exptype = 10 if clave=="N009"

	replace exptype = - 1 if clave=="T901"
	replace exptype = 6 if clave=="T902"
	replace exptype = 4 if clave=="T903"
	replace exptype =10 if clave=="T904"
	replace exptype = 7 if clave=="T905"
	replace exptype = 6 if clave=="T906"
	replace exptype = 4 if clave=="T907"
	replace exptype = 2 if clave=="T908"
	replace exptype = 4 if clave=="T909"
	replace exptype = 5 if clave=="T910"
	replace exptype = 4 if clave=="T911"
	replace exptype = 7 if clave=="T912"
	replace exptype = 6 if clave=="T913"
	replace exptype = 10 if clave=="T914"

	drop if exptype==.

	keep folioviv foliohog exptype gas_mon

	collapse (sum) gas_mon, by(folioviv foliohog exptype)

	sort folioviv foliohog exptype
	save "$data_pro\gastos_categ.dta", replace

    restore


    ** save expenditure file aggregating expenditure categories at the HH
    collapse (sum) gas_tri gas_mon , by(expnum folioviv foliohog)
    sort folioviv foliohog
    save "$data_pro\gastos_agg_cat.dta", replace

    ** save expenditure file with total expenditure at the HH
    collapse (sum) gas_tri gas_mon , by(folioviv foliohog)
    save "$data_pro\gastos_agg.dta", replace


***************
/*GASTODIARIO*/
***************

    //This table identifies the daily expenses that make each one of the members of the household and the household as a whole (numren = "00")
    //in food, drinks, tobacco and public transport during the reference period.
    // some of the expenditure is reported at the individual level, so we need to aggregate this at the HH level
    * when numren == "00" then expenditure observation refers to houshold instead of individual

    use "Mexico Raw Data\gastodiario.dta", clear

    label var folioviv "Residence identifier"

    label var foliohog "Household identifier"

    label var numren "Individual identifier"

    label var clave "code identifying type of expenditure"

    label var dia "Interview day 1-7"

    label var cantidad "quantity"
    label var lug_com "Type of shop"
    gen informal    =1 if inlist(lug_com, 1,2,3)
    replace informal=0 if informal==.
    label var informal "purchased from informal vendor"


    label  var fpago "Payment method"
    label define fpago 1 "cash" 2 "credit card" 3 "trade credit" 12 "cash & credit" 21 "cash & credit"  31 "cash and trade credit" 13 "cash and trade credit" 23 "credit card and trade credit" 32 "credit card and trade credit"
    label values fpago fpago


    label var gasto "expenditure"
    label var gas_tri "quarterly expenditure, decena taken into account"

    gen gas_mon=gas_tri/3
    label var gas_mon "montly expenditure, from gas_tri"

    * Classify goods and services according to whether they are VAT taxable or not
    * Use Hector Villarreal's code

    sort clave
    merge clave using "W:\Mexico_Fiscal_Reforms2\Hector's Model\clave e iva_sortclave.dta"

    replace iva="Exento" if iva=="Exentos"
    replace iva="Tasa Cero" if iva=="Tasa cero"

    drop if _m==2

    generate vat=1 if iva=="Exento"|iva=="Exentos"
    replace  vat=2 if iva=="Tasa Cero"
    replace  vat=3 if iva=="Gravado"

    label define vat 1 "Exempt" 2 "Zero rate" 3 "Taxed"
    label values vat vat

    drop _m

    ** generate expenditure categories
    gen     expnum="exp4"                 if ((clave>="B001"&clave<="B007") | inlist(clave, "E013", "M001", "T902")) & informal==0
    replace expnum="exp34"                if ((clave>="B001"&clave<="B007") | inlist(clave, "E013", "M001", "T902")) & informal==1

    replace expnum="exp8"                 if ((clave>="A001"&clave<="A068") | (clave>="A072"&clave<="A197") | (clave>="A203"&clave<="A215") | inlist(clave, "A070", "A218", "A242")) & informal==0
    replace expnum="exp38"                if ((clave>="A001"&clave<="A068") | (clave>="A072"&clave<="A197") | (clave>="A203"&clave<="A215") | inlist(clave, "A070", "A218", "A242")) & informal==1

    replace expnum="exp14"                if (inlist(clave, "A069", "A071", "A216", "A217")) & informal==0
    replace expnum="exp44"                if (inlist(clave, "A069", "A071", "A216", "A217")) & informal==1

    replace expnum="exp15"                if ((clave>="A198"&clave<="A202") | (clave>="A219"&clave<="A222") | (clave>="A243"&clave<="A247") | inlist(clave, "T901")) & informal==0
    replace expnum="exp45"                if ((clave>="A198"&clave<="A202") | (clave>="A219"&clave<="A222") | (clave>="A243"&clave<="A247") | inlist(clave, "T901")) & informal==1

    replace expnum="exp26"                if (inlist(clave, "A228", "A231", "A234", "A232", "A238")) & informal==0
    replace expnum="exp56"                if (inlist(clave, "A228", "A231", "A234", "A232", "A238")) & informal==1

    replace expnum="exp27"                if (inlist(clave, "A226", "A237")) & informal==0
    replace expnum="exp57"                if (inlist(clave, "A226", "A237")) & informal==1

    replace expnum="exp28"                if (inlist(clave, "A223", "A225", "A227", "A229", "A230", "A233", "A235", "A236")) & informal==0
    replace expnum="exp58"                if (inlist(clave, "A223", "A225", "A227", "A229", "A230", "A233", "A235", "A236")) & informal==1

    replace expnum="exp29"                if (inlist(clave, "A224")) & informal==0
    replace expnum="exp59"                if (inlist(clave, "A224")) & informal==1

    replace expnum="exp30"                if (inlist(clave, "A239", "A240", "A241")) & informal==0
    replace expnum="exp60"                if (inlist(clave, "A239", "A240", "A241")) & informal==1

    * aggregate all different types of expenditure at the HH level (add across individual and days)

    collapse (sum) gasto gas_tri gas_mon, by(folioviv foliohog informal clave iva descripcion expnum)

    sort folioviv foliohog

    save "$data_pro\gastodiario.dta", replace


    ** NOW DO THE CATEGORIES FOR SPENDING THAT APPEAR IN NATIONAL ACCOUNTS ***

    preserve

	gen exptype = .

	replace exptype = -1 if clave>="A001" & clave<="A214"
	replace exptype = 0 if clave>="A215" & clave<="A222"
	replace exptype = 1 if clave>="A223" & clave<="A241"
	replace exptype = 9 if clave>="A243" & clave<="A247"
	replace exptype = 6 if clave>="B001"

	keep folioviv foliohog exptype gas_mon

	collapse (sum) gas_mon, by(folioviv foliohog exptype)

	sort folioviv foliohog exptype

	save "$data_pro\gastodiario_categ.dta", replace

    restore


    collapse (sum) gas_tri gas_mon , by(expnum folioviv foliohog)

    sort folioviv foliohog

    save "$data_pro\gastodiario_agg_cat.dta", replace

    collapse (sum) gas_tri gas_mon , by(folioviv foliohog)

    sort folioviv foliohog

    save "Mexico Processed Data\gastodiario_agg.dta", replace



***************
/*GASTOEDUCA  */
***************

    use "Mexico Raw Data\gastoeduca.dta", clear

    label var folioviv "Residence identifier"

    label var foliohog "Household identifier"

    label var numren "Individual identifier"

    label var clave "code identifying type of expenditure"

    label var inscrip  "registration fee"
    label var colegia  "course fee"
    label var material "coursework material"


    label  var fpago "Payment method"
    label define fpago 1 "cash" 2 "credit card" 3 "trade credit" 12 "cash & credit" 21 "cash & credit"  31 "cash and trade credit" 13 "cash and trade credit" 23 "credit card and trade credit" 32 "credit card and trade credit"
    label values fpago fpago

    label var gas_tri "quarterly expenditure, decena taken into account"

    gen gas_mon=gas_tri/3
    label var gas_mon "montly expenditure, from gas_tri"

    * Classify goods and services according to whether they are VAT taxable or not
    * Use Hector Villarreal's code

    sort clave
    merge clave using "W:\Mexico_Fiscal_Reforms2\Hector's Model\clave e iva_sortclave.dta"

    replace iva="Exento" if iva=="Exentos"
    replace iva="Tasa Cero" if iva=="Tasa cero"

    drop if _m==2

    generate vat=1 if iva=="Exento"|iva=="Exentos"
    replace  vat=2 if iva=="Tasa Cero"
    replace  vat=3 if iva=="Gravado"

    label define vat 1 "Exempt" 2 "Zero rate" 3 "Taxed"
    label values vat vat

    drop _m


    gen         expcat="VATexempted_education" if vat==1
    replace     expcat="VATzero_education" if vat==2
    replace     expcat="VATable_education" if vat==3


    gen     expnum="exp2"                           if ((clave>="E001"&clave<="E008") | inlist(clave, "E015", "E017", "T905"))

    sort folioviv foliohog

    save "Mexico Processed Data\gastoeduca.dta", replace

    ** NOW DO THE CATEGORIES FOR SPENDING THAT APPEAR IN NATIONAL ACCOUNTS ***

    preserve

	gen exptype = .
	replace exptype = 8 if clave>="E001" & clave<="E007"

	keep folioviv foliohog exptype gas_mon

	collapse (sum) gas_mon, by(folioviv foliohog exptype)

	sort folioviv foliohog exptype
	save "$data_pro\gastoeduc_categ.dta", replace

    restore


    * add all education expenditures together at the HH level

    collapse (sum) gas_tri gas_mon, by(folioviv foliohog expnum)


    sort folioviv foliohog

    save "Mexico Processed Data\gastoeduca_agg.dta", replace

    save "Mexico Processed Data\gastoeduca_agg_cat.dta", replace



********************
/*NOMONETARIO     */
********************

    //This table identifies revenues (expenses) per household and per household member in goods and services obtained,
    //making a partial payment or without any payment


    *** generate non monetary categories to be added to monetary expenditure categories
    ************************************************************************************

    use "Mexico Raw Data\nomonetario.dta", clear


    ** drop capital and financial nonmonetary expenditure/trasnfers such as inheritance, payment of interests, etc. (clave=Q001-Q016)
    drop if clave>="Q001"&clave<="Q016"

    /*
    ** drop G001 (Own house); isn't this included in imputed rent?
    drop if clave=="G001"
    */

    label var folioviv "Residence identifier"

    label var foliohog "Household identifier"

    label var clave "code identifying type of expenditure"

    label var apoyo "value of good/service in $"

    label var apo_tri "quarterly value of good/service in $, decena taken into account"

    gen apo_mon=apo_tri/3
    label var apo_mon "monthly value of good/service in $, decena taken into account"

    * Classify goods and services according to whether they are VAT taxable or not
    * Use Hector Villarreal's code

    sort clave
    merge clave using "W:\Mexico_Fiscal_Reforms2\Hector's Model\clave e iva_sortclave.dta"

    replace iva="Exento" if iva=="Exentos"
    replace iva="Tasa Cero" if iva=="Tasa cero"
    drop if _m==2

    generate vat=1 if iva=="Exento"
    replace  vat=2 if iva=="Tasa Cero"
    replace  vat=3 if iva=="Gravado"

    label define vat 1 "Exempt" 2 "Zero rate" 3 "Taxed"
    label values vat vat

    * all is informal here
    gen clave_letter=substr(clave, 1,1)


        /**********************************/
        /* need to change this to expnum !*/
        /**********************************/

    gen     expcat="VATzero_health_and_medicine"            if clave_letter=="J" & vat==2
    replace expcat="VATexempted_health_and_medicine"        if clave_letter=="J" & (vat==1|vat==.)
    replace expcat="VATable_health_and_medicine"            if clave_letter=="J" & vat==3
    replace expcat="petrol_gasoline"        if inlist(clave, "F010","F011", "F012")
    replace expcat="telecoms"               if inlist(clave, "F001","F002","F003","F004","F005","F006","F008","F009")
    replace expcat="lottery"                if inlist(clave, "E029")
    replace expcat="transfers"              if inlist(clave, "N011", "N012", "N013","N014", "N015", "N016")
    replace expcat="cigarettes"             if inlist(clave, "A239")
    replace expcat="othertobacco"           if inlist(clave, "A240", "A241")
    replace expcat="public_transport"       if clave_letter=="B"
    replace expcat="informal_beer"          if inlist(clave, "A224")
    replace expcat="informal_alc_under14"  if inlist(clave, "A228", "A231" ,"A234", "A232", "A238")
    replace expcat="informal_alc_14_20"    if inlist(clave, "A226", "A237")
    replace expcat="informal_alc_over20"   if inlist(clave, "A223", "A225", "A227", "A229", "A230", "A233", "A235", "A236")
    replace expcat="education"              if inlist(clave, "E001","E002","E003", "E004","E005", "E006","E007")
    replace expcat="informal_VATable_food"  if expcat=="" & clave_letter=="A" & vat==3
    replace expcat="VATzero_food"        if expcat=="" & clave_letter=="A" & inlist(vat,2)
    replace expcat="VATexempted_other_nonfood"       if expcat=="" & clave_letter!="A" & inlist(vat,1,.)
    replace expcat="informal_VATable_other_nonfood" if expcat=="" & clave_letter!="A" & inlist(vat,3)


    * need to generate expnum
    cap drop gas_*
    gen gas_tri =apo_tri
    gen gas_mon =apo_mon

    sort folioviv foliohog
    save "Mexico Processed Data\gastos_nomonet.dta", replace

    ** NOW DO THE CATEGORIES FOR SPENDING THAT APPEAR IN NATIONAL ACCOUNTS ***

    preserve

	gen exptype = .
	replace exptype = 4 if clave>="C001" & clave<="C019"
	replace exptype = 10 if clave>="C020" & clave<="C022"
	replace exptype = 3 if clave>="C023" & clave<="C024"

	replace exptype = 10 if clave>="D001" & clave<="D026"

	replace exptype = 8 if clave>="E001" & clave<="E019"
	replace exptype = 7 if clave>="E020" & clave<="E033"

	replace exptype = 10 if clave>="F001" & clave<="F009"
	replace exptype = 6 if clave>="F010" & clave<="F017"

	replace exptype = 3 if clave_letter=="G"

	replace exptype = 2 if clave>="H001" & clave<="H136"

	replace exptype = 4 if clave_letter=="I"

	replace exptype = 5 if clave_letter=="J"

	replace exptype = 4 if clave>="K001" & clave<="K036"
	replace exptype = 4 if clave>="K037" & clave<="K044"

	replace exptype = 7 if clave_letter=="L"

	replace exptype = 6 if clave_letter=="M"

	replace exptype = 10 if clave>="N001" & clave<="N002"
	replace exptype = 9 if clave>="N003" & clave<="N005"
	replace exptype = 7 if clave=="N006"
	replace exptype = 10 if clave=="N007"
	replace exptype = 6 if clave=="N008"
	replace exptype = 10 if clave=="N009"

	replace exptype = - 1 if clave=="T901"
	replace exptype = 6 if clave=="T902"
	replace exptype = 4 if clave=="T903"
	replace exptype =10 if clave=="T904"
	replace exptype = 7 if clave=="T905"
	replace exptype = 6 if clave=="T906"
	replace exptype = 4 if clave=="T907"
	replace exptype = 2 if clave=="T908"
	replace exptype = 4 if clave=="T909"
	replace exptype = 5 if clave=="T910"
	replace exptype = 4 if clave=="T911"
	replace exptype = 7 if clave=="T912"
	replace exptype = 6 if clave=="T913"
	replace exptype = 10 if clave=="T914"

	replace exptype = -1 if clave>="A001" & clave<="A214"
	replace exptype = 0 if clave>="A215" & clave<="A222"
	replace exptype = 1 if clave>="A223" & clave<="A241"
	replace exptype = 9 if clave>="A243" & clave<="A247"
	replace exptype = 6 if clave_letter=="B"


	keep folioviv foliohog exptype gas_mon

	collapse (sum) gas_mon, by(folioviv foliohog exptype)

	sort folioviv foliohog exptype
	save "$data_pro\nonmon_categ.dta", replace

    restore

    collapse (sum)  gas_tri gas_mon , by(expcat folioviv foliohog)

    sort folioviv foliohog
    save "Mexico Processed Data\gastos_nomonet_agg_cat.dta", replace

    *** generate aggregate non monetary categories for income and expenditure
    *************************************************************************
    use "Mexico Raw Data\nomonetario.dta", clear

    label var folioviv "Residence identifier"

    label var foliohog "Household identifier"

    gen apo_mon=apo_tri/3
    label var apo_mon "monthly value of good/service in $, decena taken into account"

    drop apo_tri

    g double autocon= apo_mon if  ( (clave>="A001"&clave<="A247")  | (clave>="B001"&clave<="B007")| ///
                        (clave>="C001"&clave<="C024")  | (clave>="D001"&clave<="D026")| ///
                        (clave>="E001"&clave<="E033")  | (clave>="F001"&clave<="F017")| ///
                        (clave>="G002"&clave<="G022")  | (clave>="H001"&clave<="H136")| ///
                        (clave>="I001"&clave<="I026")  | (clave>="J001"&clave<="J072")| ///
                        (clave>="K001"&clave<="K036")  | (clave>="L001"&clave<="L029")| ///
                        (clave>="M001"&clave<="M018")  | (clave>="N001"&clave<="N016") ) ///
                        & tipogasto==1

    g double reminkind= apo_mon if  ( (clave>="A001"&clave<="A247")  | (clave>="B001"&clave<="B007")| ///
                        (clave>="C001"&clave<="C024")  | (clave>="D001"&clave<="D026")| ///
                        (clave>="E001"&clave<="E033")  | (clave>="F001"&clave<="F017")| ///
                        (clave>="G002"&clave<="G022")  | (clave>="H001"&clave<="H136")| ///
                        (clave>="I001"&clave<="I026")  | (clave>="J001"&clave<="J072")| ///
                        (clave>="K001"&clave<="K036")  | (clave>="L001"&clave<="L029")| ///
                        (clave>="M001"&clave<="M018")  | (clave>="N001"&clave<="N016") ) ///
                        & tipogasto==2


    g double transfer= apo_mon if  ( (clave>="A001"&clave<="A247")  | (clave>="B001"&clave<="B007")| ///
                        (clave>="C001"&clave<="C024")  | (clave>="D001"&clave<="D026")| ///
                        (clave>="E001"&clave<="E033")  | (clave>="F001"&clave<="F017")| ///
                        (clave>="G002"&clave<="G022")  | (clave>="H001"&clave<="H136")| ///
                        (clave>="I001"&clave<="I026")  | (clave>="J001"&clave<="J072")| ///
                        (clave>="K001"&clave<="K036")  | (clave>="L001"&clave<="L029")| ///
                        (clave>="M001"&clave<="M018")  | (clave>="N001"&clave<="N016")) ///
                        & inlist(tipogasto,3,4)


    g double inc_nmgains =apo_mon if  ( (clave>="Q001"&clave<="Q016")  | clave=="G001") & inlist(tipogasto, 2,3,4)


    collapse (sum) autocon reminkind transfer inc_nmgains, by(folioviv foliohog)

    label var autocon "Non-monetary Monthly Autoconsumption"
    label var reminkind "Non-monetary Monthly Remuneration Inkind"
    label var transfer "Non-monetary Monthly Transfers"
    label var inc_nmgains "Non-monetary Monthly Capital Gains"

    sort folioviv foliohog

    save "Mexico Processed Data\nomonet_agg.dta", replace


********************
/* GASTOTARJETAS  */
********************

    //we could use this to classify some HH into more informal/formal sector on top of the other markers we will use
    //also to define top income HH

    // use "Mexico Raw Data\gastotarjetas.dta", clear
